==> jc-1.4.0.tar.gz: ppg/PPG.h <==
// public class ppg.PPG

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 35a985950fb9457e ppg_PPG

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_PPG_H_
#define _JC_ppg_PPG_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_PPG$sub_refs	_jc_ppg_PPG$sub_refs;
typedef struct _jc_ppg_PPG$sub_nonrefs	_jc_ppg_PPG$sub_nonrefs;
typedef struct _jc_ppg_PPG$refs	_jc_ppg_PPG$refs;
typedef struct _jc_ppg_PPG$nonrefs	_jc_ppg_PPG$nonrefs;
typedef struct _jc_ppg_PPG$object	_jc_ppg_PPG$object;

typedef struct _jc_ppg_PPG$fields_struct	_jc_ppg_PPG$fields_struct;
typedef const struct _jc_ppg_PPG$vmethods	_jc_ppg_PPG$vmethods;
typedef const struct _jc_ppg_PPG$vtable	_jc_ppg_PPG$vtable;
typedef const struct _jc_ppg_PPG$vtype	_jc_ppg_PPG$vtype;

// Class fields structure
struct _jc_ppg_PPG$fields_struct {
	struct _jc_java_lang_String$object	*DEBUG__5fHEADER;
	struct _jc_java_lang_String$object	*HEADER;
	struct _jc_java_lang_String$object	*SYMBOL__5fCLASS__5fNAME;
	jboolean	debug;
};
extern _jc_ppg_PPG$fields_struct _jc_ppg_PPG$class_fields;

// Constructors
extern void _jc_ppg_PPG$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_PPG$object *);

// Static methods
extern void _jc_ppg_PPG$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_ppg_PPG$method$DEBUG$0ae543fb78e35b86(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_ppg_PPG$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);
extern void _jc_ppg_PPG$method$usage$266c6b1a7945f7f7(_jc_env *);

// Virtual methods structure
struct _jc_ppg_PPG$vmethods {
};

// Vtable
struct _jc_ppg_PPG$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_PPG$vmethods	ppg_PPG;
};

// Vtype
struct _jc_ppg_PPG$vtype {
	_jc_type			type;
	_jc_ppg_PPG$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_PPG$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_PPG$refs {
    _jc_ppg_PPG$sub_refs	ppg_PPG;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_PPG$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_PPG$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_PPG$sub_nonrefs	ppg_PPG;
};

// Object instance structure
struct _jc_ppg_PPG$object {
	_jc_ppg_PPG$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_PPG$vtype	*vtype;
	_jc_ppg_PPG$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_PPG$vtype _jc_ppg_PPG$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_PPG, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_PPG$class_object;

#endif	/* _JC_ppg_PPG_H_ */

==> jc-1.4.6.tar.gz: ppg/PPG.h <==
// public class ppg.PPG

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 35a985950fb9457e ppg_PPG

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_PPG_H_
#define _JC_ppg_PPG_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_PPG$sub_refs	_jc_ppg_PPG$sub_refs;
typedef struct _jc_ppg_PPG$sub_nonrefs	_jc_ppg_PPG$sub_nonrefs;
typedef struct _jc_ppg_PPG$refs	_jc_ppg_PPG$refs;
typedef struct _jc_ppg_PPG$nonrefs	_jc_ppg_PPG$nonrefs;
typedef struct _jc_ppg_PPG$object	_jc_ppg_PPG$object;

typedef struct _jc_ppg_PPG$fields_struct	_jc_ppg_PPG$fields_struct;
typedef const struct _jc_ppg_PPG$vmethods	_jc_ppg_PPG$vmethods;
typedef const struct _jc_ppg_PPG$vtable	_jc_ppg_PPG$vtable;
typedef const struct _jc_ppg_PPG$vtype	_jc_ppg_PPG$vtype;

// Class fields structure
struct _jc_ppg_PPG$fields_struct {
	struct _jc_java_lang_String$object	*DEBUG__5fHEADER;
	struct _jc_java_lang_String$object	*HEADER;
	struct _jc_java_lang_String$object	*SYMBOL__5fCLASS__5fNAME;
	jboolean	debug;
};
extern _jc_ppg_PPG$fields_struct _jc_ppg_PPG$class_fields;

// Constructors
extern void _jc_ppg_PPG$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_PPG$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_ppg_PPG$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_ppg_PPG$method$DEBUG$0ae543fb78e35b86(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_PPG$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_ppg_PPG$method$usage$266c6b1a7945f7f7(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_ppg_PPG$vmethods {
};

// Vtable
struct _jc_ppg_PPG$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_PPG$vmethods	ppg_PPG;
};

// Vtype
struct _jc_ppg_PPG$vtype {
	_jc_type			type;
	_jc_ppg_PPG$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_PPG$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_PPG$refs {
    _jc_ppg_PPG$sub_refs	ppg_PPG;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_PPG$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_PPG$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_PPG$sub_nonrefs	ppg_PPG;
};

// Object instance structure
struct _jc_ppg_PPG$object {
	_jc_ppg_PPG$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_PPG$vtype	*vtype;
	_jc_ppg_PPG$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_PPG$vtype _jc_ppg_PPG$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_PPG, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_PPG$class_object;

#endif	/* _JC_ppg_PPG_H_ */
